#Python 3.6.2 (v3.6.2:5fd33b5, Jul  8 2017, 04:14:34) [MSC v.1900 32 bit (Intel)] on win32
#Type "copyright", "credits" or "license()" for more information.
L=[1,2,3]
for i in range(len(L)):    #Add one to each number in L
	L[i]+=1            #Or L[i]=L[i]+1

print(L)